@@ -1,11 +1,17 @@
 #' Estimate mode (most frequent value)   
 #' 
-#' Estimate mode, ie most frequent value. The argument \code{method} allows to choose among (so far) 3 different methods available.
+#' Estimate mode, ie most frequent value. In case of continuous numeric data, the most frequent values may not be the most frequently repeated exact term.
+#' This function offers various approches to estimate the mode of a numeric vector. 
+#' Besides, it can also be used to identify the most frequentexact term (in this case also from character vectors). 
+#'
+#' @details
+#' The argument \code{method} allows to choose among (so far) 4 different methods available.
 #' If "density" is chosen, the most dense region of sqrt(n) values will be chosen; 
 #' if "binning", the data will be binned (like in histograms) via rounding to a user-defined number of significant values ("rangeSign").
 #' If \code{method} is set to "BBmisc", the function \code{computeMode()} from package \href{https://CRAN.R-project.org/package=BBmisc}{BBmisc} will be used.
+#' If "mode" is chosen, the first most frequently occuring (exact) value will be returned, if "allModes", all ties will be returned. This last mode also works with character input. 
 #'	 
-#' @param x (numeric) data to treat
+#' @param x (numeric, or character if 'method='mode') data to find/estimate most frequent value
 #' @param method (character) There are 3 options : BBmisc, binning and density (default). If "binning" the function will search context dependent, ie like most frequent class of histogram.
 #'  Using "binning" mode the search will be refined if either 80 percent of values in single class or >50 percent in single class.
 #' @param bandw (integer) only used when \code{method="binning"} or  \code{method="density"} : defines the number of points to look for density or number of classes used; 
@@ -33,14 +39,30 @@ stableMode <- function(x, method="density", bandw=NULL, rangeSign=1:6, nCl=NULL,
   } else if(length(unique(x)) == 1) {
     method <- NULL
     return(x[1])
-    if(!silent) message(fxNa, " all values are the same (= mode)") }
+    if(!silent &  length(x) >1) message(fxNa, " all values are the same (= mode)") }
   if(identical(method, "dens"))  method <- "density"
   if(identical(method, "bin")) method <- "binning"
   if(identical(method, "histLike")) {
     method <- "binning"
     if(!silent) message(fxNa, " Note: argument option 'histLike' has been depreciated and replaced by 'binning'") }
   out <- NULL
-  chDu <- sum(duplicated(x))
+  isNum <- is.numeric(x)
+  ## check type of input
+  if(any(sapply(c("BBmisc","density","binning"), identical, method)) & !isNum) {    
+    chNum <- try(as.numeric(if(is.factor(x)) as.character(x) else x))
+    if("try-error" %in% class(chNum)) {
+     if(!silent) message(fxNa," Note : Input is NOT numeric, not compatible with method chosen, thus setting method='mode' !")
+     method <- "mode"
+  }}
+  ## find simply most frequent exact value(s)
+  if(any(sapply(c("allModes","mode","asIs"), identical, method))) {
+    if(!is.factor(x)) x <- factor(as.character(x))
+    tabX <- tabulate(x)
+    out <- if(identical(method, "allModes")) {
+      levels(x)[which(tabX == max(tabX))]
+    } else levels(x)[which.max(tabX)]
+    if(isNum) out <- as.numeric(out)
+  } else  chDu <- sum(duplicated(x)) 
   ## BBmisc
   if(identical(method, "BBmisc")) {
     chPa <- try(find.package("BBmisc"), silent = TRUE)
